README FILE

Datum library

Datum is a robot framework library that provide interesting keywords to handle pdf files and compare text.

Installation
The recommended installation method is pip:
pip install robotframework-datum

Running this command installs also the latest version of Requests.
